import os
import pyfbi
from xbrr.client.document_client import DocumentClient
from xbrr.reader.edinet.xbrl_reader import XBRLReader
from xbrr.reader.edinet.aspects.finance import Finance


@pyfbi.target
def check():
    _dir = os.path.join(os.path.dirname(__file__), "./tests/data")
    client = DocumentClient()
    file_path = client.get_xbrl("S100G2KL", save_dir=_dir,
                                expand_level="dir")
    reader = XBRLReader(file_path)
    bs = reader.extract(Finance).bs()
    bs.to_csv("bs.csv", index=False, encoding="shift_jis")


with pyfbi.watch():
    check()

pyfbi.dump("result")
pyfbi.show()



import os
import unittest
from xbrr.edinet.reader.reader import Reader
from xbrr.edinet.reader.aspects.company import Company


class TestCompany(unittest.TestCase):

    def get_xbrl(self):
        path = os.path.join(os.path.dirname(__file__),
                            "../../data/xbrl2019.xbrl")
        xbrl = Reader(path)
        return xbrl

    def test_history(self):
        xbrl = self.get_xbrl()
        feature = xbrl.extract(Company).history
        self.assertTrue(feature.normalized_text.startswith("2【沿革】"))

    def test_business_description(self):
        xbrl = self.get_xbrl()
        feature = xbrl.extract(Company).business_description
        self.assertTrue(feature.normalized_text.startswith("3【事業の内容】"))

    def test_affiliated_entities(self):
        xbrl = self.get_xbrl()
        feature = xbrl.extract(Company).affiliated_entities
        self.assertTrue(feature.normalized_text.startswith("4【関係会社の状況】"))

    def test_employees(self):
        xbrl = self.get_xbrl()
        feature = xbrl.extract(Company).employees
        self.assertTrue(feature.normalized_text.startswith("5【従業員の状況】"))
